<template>
  <div>
    <el-dialog title="成果形式" width="80%" top="6vh" :close-on-click-modal="false" :visible.sync="dialogFormVisible">
      <el-form v-if="!isEdit" :model="resultForm" :rules="resultRule" label-position="top" ref="result">
        <el-row :gutter="24" justify="start" type="flex" class="flex-wrap">
          <el-col :span="8">
            <el-form-item label="成果名称" :label-width="formLabelWidth" prop="resultName">
              <el-input :disabled="isEdit" v-model="resultForm.resultName" type="text" placeholder="请输入成果名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="成果形式" :label-width="formLabelWidth" prop="resultForm">
              <dict-select dictCode="ggsd_cgxs" :hasDefaultOption="true" clearable :disabled="isEdit"
                v-model="resultForm.resultForm" style="width: 100%" placeholder="请选择成果形式" />
            </el-form-item>
          </el-col>

          <el-col :span="8">
            <el-form-item label="成果形成日期" :label-width="formLabelWidth" prop="resultDate">
              <el-date-picker v-model="resultForm.resultDate" type="date" :disabled="isEdit" width="100%"
                placeholder="请选择成果形成日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="具体举措及解决问题" :label-width="formLabelWidth" prop="solveProblem">
              <el-input type="textarea" :rows="5" maxlength="200" v-model="resultForm.solveProblem" autocomplete="off"
                show-word-limit placeholder="请条目式列举总结相关试点举措解决的突出问题"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="具体成效" :label-width="formLabelWidth" prop="actualEffect">
              <el-input type="textarea" :rows="5" maxlength="200" v-model="resultForm.actualEffect" autocomplete="off"
                show-word-limit placeholder="请条目式列举相关试点成果被复制推广、被上级表彰肯定、获5家中央媒体报道等情况。"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="上传附件" prop="">
              <el-button class="updload_btn" size="small" type="primary" @click="openUploade">
                点击上传</el-button>
              <span style="font-size:13px;color:red">
                * (请上传相关试点成果取得实效的佐证材料，以图片或pdf为主)</span>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <span style="font-size:13px;color:red" v-if="resultForm.classified && !fileList.length">
              文件涉密，已通过内网上传。</span>
            <template>
              <FileList @changeFileList="changeFileList($event)" @idExist="idExist" :fileList="fileList" :isDelete="true"
                :isRequest="isRequest">
              </FileList>
            </template>
            <!-- <el-col :span="12" v-for="(file, index) in fileList" :key="index">
              <div class="file-style">
                <div class="file-item">
                  <span class="file-name">{{
                    file.name
                      ? file.name
                      : file.fileName + '.' + file.extensionName
                  }}</span>
                  <span>
                    <el-link
                      type="primary"
                      :underline="false"
                      @click="handlePreview(file)"
                      >预览</el-link
                    >
                    <el-link
                      type="primary"
                      :underline="false"
                      @click="handleDownloadFile(file)"
                      >下载</el-link
                    >
                    <el-link
                      type="danger"
                      :underline="false"
                      @click="beforeRemove(file)"
                      >删除</el-link
                    >
                  </span>
                </div>
              </div>
            </el-col> -->
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="dialogFormVisible = false">取 消</el-button>
        <el-button type="primary" @click="saveResultData" v-if="!isEdit">保存</el-button>
      </div>
    </el-dialog>
    <UploadFile ref="uploadFile" @setFileList="setFileList" @setAipher="setAipher" />
    <filePreview ref="filePreview" :previewUrl="dialogImageUrl"> </filePreview>
  </div>
</template>

<script>
import moment from 'moment'
import sat from '@/api/satisfaction/satisfaction'
import filePreview from '@/components/FilePreview/filePreview.vue'
import UploadFile from '@/components/uploadFile/index.vue'
// import FileList from '@/components/uploadFile/newFileList.vue'
import FileList from '@/components/uploadFile/FileList.vue'
const portal = window.context.portal
import utils from '@/utils.js'
export default {
  name: 'FormResultsDialog',
  components: {
    filePreview,
    UploadFile,
    FileList
  },
  data() {
    return {
      dialogFormVisible: false,
      formLabelWidth: '120px',
      resultForm: {
        resultName: '',
        resultForm: '',

        resultDate: '',
        ids: [],
        solveProblem: '',
        actualEffect: '',
        id: ''
      },
      fileList: [],
      disabled: false,
      imgLoading: false,
      resultRule: {
        resultForm: [
          { required: true, message: '请选择成果形式', trigger: 'change' }
        ],
        resultDate: [
          {
            required: true,
            message: '请选择成果形成日期',
            trigger: 'change'
          }
        ],
        resultName: [
          { required: true, message: '请输入成果名称', trigger: 'blur' }
        ],
        classified: [
          { required: true, message: '请选择文件是否涉密', trigger: 'change' }
        ]
      },
      dialogImageUrl: '',
      dialogVisible: false,
      isEdit: false,
      // 文件是否涉密
      cipher: false,
      classified: 0,
      reslultIds: [],
      removeIds: [],
      isRequest: true
    }
  },
  methods: {
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    // 打开弹窗
    open(item) {
      console.log(item)
      this.dialogFormVisible = true
      this.resultForm = item
      this.fileList = item.fileList || []
      this.classified = item.classified
    },
    // 关闭弹窗
    closeResultForm() {
      this.dialogFormVisible = false
      this.fileList = []
      this.removeIds = []
      this.$refs.result.resetFields()
      this.classified = 0
    },
    openUploade() {
      this.$refs.uploadFile.open('PilotResult')
    },
    setFileList(file) {
      this.fileList.push(file)
      this.classified = 0
    },
    beforeRemove(file, fileList) {
      let name = file.name
        ? file.name
        : file.fileName + '.' + file.extensionName
      this.$confirm(`确定删除 ${name}？`, this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning'
      }).then(() => {
        let id = file.fileId
          ? file.fileId
          : file.id
            ? file.id
            : file.response.fileId
        sat.deleteFileById(id, res => {
          if (res.state) {
            this.$message.success('附件删除成功')
            let arr = this.fileList.filter(item => {
              let fileId = item.id || item.response.fileId
              if (fileId !== id) {
                return item
              }
            })
            if (arr.length == 0) {
              this.classified = 0
            }
            this.fileList = arr
          } else {
            this.$message.error('附件删除失败')
          }
        })
      })
    },
    handlePreview(file) {
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      this.dialogImageUrl = this.previewUrl + id

      let type = file.fileType || (file.extensionName
        ? file.extensionName
        : file.name.split('.')[1])
      this.$refs.filePreview.previewUrl = this.previewUrl + id
      this.$refs.filePreview.open(type)
    },
    // 文件下载
    handleDownloadFile(file) {
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
    },
    changeFileList(arr) {
      this.fileList = arr
    },
    idExist(id) {
      if (!this.reslultIds.includes(id)) {
        // this.isRequest = false
        this.removeIds.push(id)
      }
      // else {
      //   this.isRequest = true
      // }
    },
    // 保存数据
    setAipher(val) {
      this.cipher = val
      this.classified = 1
      this.saveResultData()
    },
    saveResultData() {
      let data = JSON.parse(JSON.stringify(this.resultForm))
      this.$refs.result.validate(valid => {
        let falg =
          (valid && this.classified) || (valid && this.fileList.length != 0)
        if (falg) {
          data.classified = this.classified
          data.fileList = this.fileList
          // data.ids = this.fileList.map(item => item.id || item.response.fileId)
          data.resultDate = moment(this.resultForm.resultDate).format(
            'YYYY-MM-DD'
          )
          this.$emit('pushResult', data, this.removeIds)
          this.closeResultForm()
          this.cipher = false
        } else {
          if (!valid) {
            this.$confirm('请填写完整信息。', '提示', {
              cancelButtonText: '关闭',
              showConfirmButton: false,
              type: 'error'
            })
          } else if (this.classified != 1 && this.fileList.length == 0) {
            this.$confirm('请上传佐证材料后保存。', '提示', {
              confirmButtonText: '立即上传',
              cancelButtonText: '关闭',
              type: 'error'
            }).then(() => {
              this.openUploade()
            })
          }
        }
      })
    }
    // 查看详情
  }
}
</script>

<style lang="scss" scoped>
.upload_file {
  opacity: 1;
  height: 100%;
  pointer-events: auto;
  transition: all 0.3s;
}

.upload_file_none {
  opacity: 0;
  height: 0;
  pointer-events: none;
  transition: all 0.3s;

  .upload-demo {
    display: none;
  }
}

/deep/ .el-upload--picture-card {
  display: block;
  border: none;
  width: 100%;
  height: 70px;
  line-height: 70px;
  text-align: left;
}

/deep/.el-upload-list--picture-card .el-upload-list__item {
  width: 100px;
  height: 70px;
}

/deep/ .upload-demo {
  pointer-events: auto;

  .el-upload-list {
    display: flex;

    > {
      flex: 1;
    }
  }
}

/deep/ .btn-show {
  .el-upload--picture-card {
    height: 0 !important;
    width: 0;
    opacity: 0;
    pointer-events: none;
  }
}

/deep/ .is-success {
  .el-loading-mask {
    display: none;
  }
}

/deep/ .el-loading-mask {
  height: 70px;

  .el-loading-spinner {
    top: 60%;
  }
}

/deep/.el-descriptions__header {
  margin: 15px 0 0 0;

  .el-descriptions__title {
    font-weight: normal;
  }
}

.file-item {
  display: flex;
  justify-content: space-between;
  width: 100%;
  padding: 5px 5px 5px 0;

  a {
    margin: 0 10px;
    user-select: none;
  }

  .file-name {
    max-width: 220px;
    height: 22px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
  }
}

.file-item:hover {
  background-color: #f5f5f5;
  border-radius: 2px;
}
</style>
